@@ -298,6 +298,9 @@ class API(Record('url', 'http')):
 
         :param headers:
             A dictionary of raw HTTP headers to send.
+
+        Note that if a non-successful response is returned, an instance of
+        :class:`intessa.Error` will be *raised*.
         """
 
         method = kwargs.pop('method', 'GET')
